#!/usr/bin/env node
const commander = require('commander');
const program = new commander.Command();
var shell = require('shelljs');

function validateDependencies() {
    if (!shell.which('git')) {
        shell.echo('git not installed');
        shell.exit(1);
    }

    if (!shell.which('haxe')) {
        shell.echo('haxe is not installed');
        shell.exit(1);
    }
}

function buildDependencies() {
    let haxelibCmd = 'haxelib';
    if (shell.which('npx')) {
        shell.echo('npx is available');
        haxelibCmd = 'npx --no-install haxelib';
    }
    if (shell.test('-d', './.haxelib')) {
        shell.echo('removing old dependencies')
        shell.exec(`${haxelibCmd} deleterepo`);
    }
    shell.exec(`${haxelibCmd} newrepo`);

    if (shell.test('-f', './haxelib.json')) {
        shell.echo('installing dependencies from haxelib.json');
        shell.exec(`${haxelibCmd} install ./haxelib.json --always`);
    } else {
        shell.echo('haxelib.json not found');
        shell.exit(1);
    }
}

program
    .command('setup')
    .description('Cleans old dependencies and installs dependencies from haxelib.json')
    .action(function() {
        validateDependencies();
        buildDependencies();
    });

program
    .command('build')
    .description('Builds the given .hxml file after setting up dependencies')
    .option('--no-dependency', 'Build hxml without setting up dependencies')
    .arguments('<file>')
    .action(function(file, option) {
        if (!file.endsWith('.hxml')) {
            var errorMessage = `${file} is not a hxml file`;
            shell.echo(errorMessage);
            shell.exit(1);
        }

        validateDependencies();
        if (option.dependency) {
            buildDependencies();
        }
        let haxeCmd = 'haxe';
        if (shell.which('npx')) {
            shell.echo('npx is available');
            haxeCmd = 'npx --no-install haxe';
        }
        shell.echo('Building hxml');
        var buildCommand = `${haxeCmd} ${file}`;
        shell.exec(buildCommand);
    });

program.parse(process.argv);